import React, { useEffect, useState } from "react";
import { StyleSheet } from "react-native";
import Animated, { useAnimatedStyle, useSharedValue, withTiming } from "react-native-reanimated";
const styles = StyleSheet.create({
    container: {
        overflow: 'hidden',
        width: '100%'
    }
});
const AccordionView = ({ visible, children }) => {
    const [opened, setOpened] = useState(false);
    const opacity = useSharedValue(0);
    const maxHeight = useSharedValue(100);
    const viewStyle = useAnimatedStyle(() => {
        return {
            opacity: opacity.value,
            maxHeight: maxHeight.value + '%'
        };
    });
    useEffect(() => {
        toggleList(visible);
    }, [visible]);
    const toggleList = (show) => {
        if (!show) {
            opacity.value = withTiming(0, {
                duration: 300
            });
            maxHeight.value = withTiming(0, {
                duration: 300
            });
            setTimeout(() => {
                setOpened(false);
            }, 300);
        }
        else {
            setOpened(true);
            opacity.value = withTiming(1, {
                duration: 300
            });
            maxHeight.value = withTiming(100, {
                duration: 300
            });
        }
    };
    return (opened ?
        <Animated.View style={[styles.container, viewStyle]}>
        {children}
      </Animated.View>
        : null);
};
export { AccordionView };
//# sourceMappingURL=AccordionView.js.map