import React, { useCallback, useEffect, useState } from 'react';
import isEqual from 'react-fast-compare';
import { FlatList, Pressable } from 'react-native';
import globalHook from 'use-global-hook';
import { AccordionView } from './AccordionView';
const actions = {
    setOpenedNode: (store, { internalId, opened }) => {
        store.setState({
            nodesState: Object.assign(Object.assign({}, store.state.nodesState), { [internalId]: opened }),
        });
    },
};
const useGlobal = globalHook(React, {
    nodesState: { root: true },
}, actions);
const NodeView = React.memo(({ renderNode, extraData, level, getChildrenName, node, onNodePressed, keepOpenedState, }) => {
    const [globalState, globalActions] = useGlobal();
    const [_node, setNode] = useState(Object.assign(Object.assign({}, node), { opened: keepOpenedState && globalState.nodesState[node._internalId]
            ? !!globalState.nodesState[node._internalId]
            : !!node.opened }));
    useEffect(() => {
        setNode(Object.assign(Object.assign({}, node), { opened: _node.opened }));
    }, [node, _node.opened]);
    const _onNodePressed = () => {
        if (keepOpenedState) {
            globalActions.setOpenedNode({
                internalId: _node._internalId,
                opened: !_node.opened,
            });
        }
        setNode(Object.assign(Object.assign({}, _node), { opened: !_node.opened }));
        if (onNodePressed) {
            onNodePressed(_node);
        }
    };
    const renderChildren = useCallback((item, _level) => (<NodeView getChildrenName={getChildrenName} node={item} level={_level + 1} extraData={extraData} onNodePressed={onNodePressed} renderNode={renderNode} keepOpenedState={keepOpenedState}/>), [extraData, getChildrenName, onNodePressed, renderNode, keepOpenedState]);
    const renderItem = useCallback(({ item }) => renderChildren(item, level), [renderChildren, level]);
    const nodeChildrenName = getChildrenName(_node);
    const nodeChildren = _node[nodeChildrenName];
    const isNodeOpened = (keepOpenedState && globalState.nodesState[node._internalId]) ||
        _node.opened;
    return (<>
        {!_node.hidden ? (<Pressable onPress={_onNodePressed}>
            {renderNode(_node, level, !nodeChildren || !nodeChildren.length)}
          </Pressable>) : null}
        <AccordionView visible={isNodeOpened && nodeChildren != null && nodeChildren.length > 0}>
          <FlatList data={nodeChildren} renderItem={renderItem} extraData={extraData} keyExtractor={(item) => item._internalId}/>
        </AccordionView>
      </>);
}, isEqual);
export { NodeView };
//# sourceMappingURL=NodeView.js.map